// Define the margin, width, and height of the SVG element
const margin = { top: 20, right: 20, bottom: 40, left: 50 };
const width = 600 - margin.left - margin.right;
const height = 400 - margin.top - margin.bottom;

// Define the radius of the circles
const radius = 5;

// Define the color and shape of each iris species
const color = {
  setosa: '#1f77b4',
  versicolor: '#ff7f0e',
  virginica: '#2ca02c'
};
const shape = {
  setosa: 'circle',
  versicolor: 'square',
  virginica: 'triangle'
};

// Define the function to create the scatter plot
const createScatterPlot = (data, xColumn, yColumn) => {
  // Create the SVG element and set its dimensions
  const svg = d3.create("svg")
      .attr("viewBox", `0 0 ${width + margin.left + margin.right} ${height + margin.top + margin.bottom}`)
      .append("g")
      .attr("transform", `translate(${margin.left}, ${margin.top})`);

  // Define the x and y scales
  const xScale = d3.scaleLinear()
      .domain(d3.extent(data, d => d[xColumn]))
      .range([0, width]);

  const yScale = d3.scaleLinear()
      .domain(d3.extent(data, d => d[yColumn]))
      .range([height, 0]);

  // Add the x and y axes to the plot
  const xAxis = g => g.attr("transform", `translate(0, ${height})`)
      .call(d3.axisBottom(xScale).ticks(5));
      
  const yAxis = g => g.call(d3.axisLeft(yScale));

  svg.append("g")
      .call(xAxis);

  svg.append("g")
      .call(yAxis);

  // Add the circles to the plot, with different colors and shapes for each iris species
  svg.selectAll("circle")
      .data(data)
      .join("circle")
        .attr("cx", d => xScale(d[xColumn]))
        .attr("cy", d => yScale(d[yColumn]))
        .attr("r", radius)
        .attr("fill", d => color[d.species])
        .attr("stroke", "black")
        .attr("stroke-width", 0.5)
        .attr("stroke-opacity", 0.8)
        .attr("fill-opacity", 0.7)
        .attr("shape-rendering", "geometricPrecision")
        .attr("vector-effect", "non-scaling-stroke")
        .attr("class", d => `species-${d.species}`)
        .attr("shape", d => shape[d.species]);

  // Return the SVG element for the scatter plot
  return svg.node();
};

// Load the CSV data and create the scatter plot with the default columns
d3.csv("https://gist.githubusercontent.com/snehareddygurram/e19d8f7bf75b3021fa64bc421f0f95a6/raw/0a733f977c84da13bf59e9ad8cdf3c79a7c94959/iris_data.csv", d3.autoType).then(data => {
  createScatterPlot(data, "sepal_length", "sepal_width");
});






